pub struct ShipmentItem {
pub ASIN: Option<String>,
pub seller_sku: Option<String>,
pub order_item_id: Option<String>,
pub title: Option<String>,
pub quantity_ordered: Option<f32>,
pub item_price: Option<Box<Money>>,
pub shipping_price: Option<Box<Money>>,
pub gift_wrap_price: Option<Box<Money>>,
pub shipping_discount: Option<Box<Money>>,
pub promotion_discount: Option<Box<Money>>,
pub serial_numbers: Option<Vec<String>>,
}Expand description
ShipmentItem : The shipment item information required by a seller to issue a shipment invoice.
Fields
ASIN: Option<String>The Amazon Standard Identification Number (ASIN) of the item.
seller_sku: Option<String>The seller SKU of the item.
order_item_id: Option<String>The Amazon-defined identifier for the order item.
title: Option<String>The name of the item.
quantity_ordered: Option<f32>The number of items ordered.
item_price: Option<Box<Money>>shipping_price: Option<Box<Money>>gift_wrap_price: Option<Box<Money>>shipping_discount: Option<Box<Money>>promotion_discount: Option<Box<Money>>serial_numbers: Option<Vec<String>>The list of serial numbers.
Implementations
sourceimpl ShipmentItem
impl ShipmentItem
sourcepub fn new() -> ShipmentItem
pub fn new() -> ShipmentItem
The shipment item information required by a seller to issue a shipment invoice.